/*
 * The Apache Software License, Version 1.1
 *
 *
 * Copyright (c) 2002 The Apache Software Foundation.  All rights 
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer. 
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:  
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The names "WSIF" and "Apache Software Foundation" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written 
 *    permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache",
 *    nor may "Apache" appear in their name, without prior written
 *    permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 * ====================================================================
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the Apache Software Foundation and was
 * originally based on software copyright (c) 2001, 2002, International
 * Business Machines, Inc., http://www.apache.org.  For more
 * information on the Apache Software Foundation, please see
 * <http://www.apache.org/>.
 */

package org.apache.wsif.providers.soap.apachesoap;

import java.io.IOException;
import java.io.Writer;

import org.apache.soap.rpc.SOAPContext;
import org.apache.soap.util.Bean;
import org.apache.soap.util.xml.Deserializer;
import org.apache.soap.util.xml.NSStack;
import org.apache.soap.util.xml.QName;
import org.apache.soap.util.xml.Serializer;
import org.apache.soap.util.xml.XMLJavaMappingRegistry;
import org.apache.wsif.logging.Trc;
import org.w3c.dom.Node;

public class SOAPEncSerializerWrapper implements PartSerializer {
    
    private Serializer targetSerializer = null;
    private Deserializer targetDeserializer = null;
    private Object part = null;
    
    /**
     * @see PartSerializer#setPart(Object)
     */
    public void setPart(Object aPart) {
        this.part = aPart;
    }

    /**
     * @see PartSerializer#getPart()
     */
    public Object getPart() {
        return this.part;
    }

    /**
     * @see PartSerializer#getPart(Class)
     */
    public Object getPart(Class partClass) {
        return null;
    }

    /**
     * @see PartSerializer#getPartQName()
     */
    public javax.xml.namespace.QName getPartQName() {
        return null;
    }

    /**
     * @see PartSerializer#setPartQName(QName)
     */
    public void setPartQName(javax.xml.namespace.QName qName) {
    }

    /**
     * @see Serializer#marshall(String, Class, Object, Object, Writer, 
     * NSStack, XMLJavaMappingRegistry, SOAPContext)
     */
    public void marshall(
        String inScopeEncStyle,
        Class javaType,
        Object src,
        Object context,
        Writer sink,
        NSStack nsStack,
        XMLJavaMappingRegistry xjmr,
        SOAPContext ctx)
        throws IllegalArgumentException, IOException {
        Trc.entry(
            this,
            inScopeEncStyle,
            javaType,
            src,
            context,
            sink,
            nsStack,
            xjmr,
            ctx);
        if (this.targetSerializer != null)
            this.targetSerializer.marshall(
                inScopeEncStyle,
                javaType,
                this.part,
                context,
                sink,
                nsStack,
                xjmr,
                ctx);
        Trc.exit();
    }

    /**
     * @see Deserializer#unmarshall(String, QName, Node, XMLJavaMappingRegistry, 
     * SOAPContext)
     */
    public Bean unmarshall(
        String inScopeEncStyle,
        QName elementType,
        Node src,
        XMLJavaMappingRegistry xjmr,
        SOAPContext ctx)
        throws IllegalArgumentException {
        Trc.entry(this, inScopeEncStyle, elementType, xjmr, ctx);
        Bean b = null;
        if (this.targetDeserializer != null)
            b =
                this.targetDeserializer.unmarshall(
                    inScopeEncStyle,
                    elementType,
                    src,
                    xjmr,
                    ctx);
        Trc.exit(b);
        return b;
    }

    /**
     * Gets the targetDeserializer.
     * @return Returns a Deserializer
     */
    public Deserializer getTargetDeserializer() {
        return targetDeserializer;
    }

    /**
     * Sets the targetDeserializer.
     * @param targetDeserializer The targetDeserializer to set
     */
    public void setTargetDeserializer(Deserializer targetDeserializer) {
        this.targetDeserializer = targetDeserializer;
    }

    /**
     * Gets the targetSerializer.
     * @return Returns a Serializer
     */
    public Serializer getTargetSerializer() {
        return targetSerializer;
    }

    /**
     * Sets the targetSerializer.
     * @param targetSerializer The targetSerializer to set
     */
    public void setTargetSerializer(Serializer targetSerializer) {
        this.targetSerializer = targetSerializer;
    }

}