/*
 * The Apache Software License, Version 1.1
 *
 *
 * Copyright (c) 2002 The Apache Software Foundation.  All rights 
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer. 
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:  
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The names "WSIF" and "Apache Software Foundation" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written 
 *    permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache",
 *    nor may "Apache" appear in their name, without prior written
 *    permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 * ====================================================================
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the Apache Software Foundation and was
 * originally based on software copyright (c) 2001, 2002, International
 * Business Machines, Inc., http://www.apache.org.  For more
 * information on the Apache Software Foundation, please see
 * <http://www.apache.org/>.
 */

package org.apache.wsif.wsdl.extensions.format;

import java.io.Serializable;
import java.util.Iterator;
import java.util.List;

import javax.wsdl.extensions.ExtensionRegistry;
import javax.wsdl.factory.WSDLFactory;
import javax.wsdl.xml.WSDLReader;
import javax.xml.namespace.QName;

import org.apache.wsif.logging.Trc;
import org.w3c.dom.Element;

import com.ibm.wsdl.Constants;
import com.ibm.wsdl.util.xml.DOMUtils;
import com.ibm.wsdl.util.xml.QNameUtils;

/**
 * @author Owen Burroughs <owenb@apache.org>
 * @author Ant Elder <antelder@apache.org>
 * @author Jeremy Hughes <hughesj@apache.org>
 * @author Mark Whitlock <whitlock@apache.org>
 */
public class FormatBindingSerializer
    implements
        javax.wsdl.extensions.ExtensionDeserializer,
        javax.wsdl.extensions.ExtensionSerializer,
        Serializable {
	private static final long serialVersionUID = 1L;
    /**
     * ConnectorBindingSerializer constructor comment.
     */
    public FormatBindingSerializer() {
        super();
        Trc.entry(this);
        Trc.exit();
    }

    /**
      * 
      */
    public void marshall(
        Class parentType,
        QName elementType,
        javax.wsdl.extensions.ExtensibilityElement extension,
        java.io.PrintWriter pw,
        javax.wsdl.Definition def,
        javax.wsdl.extensions.ExtensionRegistry extReg)
        throws javax.wsdl.WSDLException {
        Trc.entry(this, parentType, elementType, extension, pw, def, extReg);

        if (extension == null) {
            Trc.exit();
            return;
        }

        if (extension instanceof TypeMapping) {
            TypeMapping typeMapping = (TypeMapping) extension;
            pw.print("         <format:typeMapping");

            String style = typeMapping.getStyle();
            if (style != null)
                DOMUtils.printAttribute("style", style, pw);
            String encoding = typeMapping.getEncoding();
            if (encoding != null)
                DOMUtils.printAttribute("encoding", encoding, pw);
            pw.println(">");

            List maps = typeMapping.getMaps();
            Iterator iterator = maps.iterator();
            while (iterator.hasNext()) {
                TypeMap typeMap = (TypeMap) iterator.next();
                pw.print("            <format:typeMap");

                // Need definition to resolve namespace to prefix to do it properly
                QName elementName = typeMap.getElementName();
                if (elementName != null) {
                    String prefix =
                        def.getPrefix(elementName.getNamespaceURI());
                    DOMUtils.printAttribute(
                        "elementName",
                        prefix + ":" + elementName.getLocalPart(),
                        pw);
                }
                QName typeName = typeMap.getTypeName();
                if (typeName != null) {
                    String prefix = def.getPrefix(typeName.getNamespaceURI());
                    DOMUtils.printAttribute(
                        "typeName",
                        prefix + ":" + typeName.getLocalPart(),
                        pw);
                }
                String formatType = typeMap.getFormatType();
                if (formatType != null)
                    DOMUtils.printAttribute("formatType", formatType, pw);
                pw.println("/>");
                Boolean required = extension.getRequired();

                if (required != null) {
                    DOMUtils.printQualifiedAttribute(
                        Constants.Q_ATTR_REQUIRED,
                        required.toString(),
                        def,
                        pw);
                }

            }
            pw.println("         </format:typeMapping>");

        }
        Trc.exit();
    }

    /**
     * Registers the serializer.
     */
    public void registerSerializer(ExtensionRegistry registry) {
        Trc.entry(this, registry);

        // Binding
        registry.registerSerializer(
            javax.wsdl.Binding.class,
            FormatBindingConstants.Q_ELEM_FORMAT_BINDING,
            this);

        registry.registerDeserializer(
            javax.wsdl.Binding.class,
            FormatBindingConstants.Q_ELEM_FORMAT_BINDING,
            this);
        Trc.exit();
    }

    /**
     * unmarshall method comment.
     */
    public javax.wsdl.extensions.ExtensibilityElement unmarshall(
        Class parentPart,
        javax.xml.namespace.QName elementPart,
        org.w3c.dom.Element el,
        javax.wsdl.Definition def,
        javax.wsdl.extensions.ExtensionRegistry extReg)
        throws javax.wsdl.WSDLException {
        Trc.entry(this, parentPart, elementPart, el, def, extReg);

        javax.wsdl.extensions.ExtensibilityElement returnValue = null;

        if (FormatBindingConstants.Q_ELEM_FORMAT_BINDING.equals(elementPart)) {
            TypeMapping typeMapping = new TypeMapping();

            String style = DOMUtils.getAttribute(el, "style");
            String encoding = DOMUtils.getAttribute(el, "encoding");
            String requiredStr =
                DOMUtils.getAttributeNS(
                    el,
                    Constants.NS_URI_WSDL,
                    Constants.ATTR_REQUIRED);

            if (style != null) {
                typeMapping.setStyle(style);
            }
            if (encoding != null) {
                typeMapping.setEncoding(encoding);
            }

            Element tempEl = DOMUtils.getFirstChildElement(el);
            while (tempEl != null) {
                if (QNameUtils
                    .matches(
                        FormatBindingConstants.Q_ELEM_FORMAT_BINDING_MAP,
                        tempEl)) {
                    TypeMap typeMap = new TypeMap();

                    QName qElementName =
                        DOMUtils.getQualifiedAttributeValue(
                            tempEl,
                            "elementName",
                            "typeMap",
                            false);
                    QName qTypeName =
                        DOMUtils.getQualifiedAttributeValue(
                            tempEl,
                            "typeName",
                            "typeMap",
                            false);

                    String formatType =
                        DOMUtils.getAttribute(tempEl, "formatType");
                    if (qElementName != null) {
                        typeMap.setElementName(qElementName);
                    }
                    if (qTypeName != null) {
                        typeMap.setTypeName(qTypeName);
                    }
                    if (formatType != null) {
                        typeMap.setFormatType(formatType);
                    }
                    typeMapping.addMap(typeMap);
                }
                tempEl = DOMUtils.getNextSiblingElement(tempEl);
            }
            Trc.exit(typeMapping);
            return typeMapping;
        }
        Trc.exit(returnValue);
        return returnValue;
    }
}