/*
 * The Apache Software License, Version 1.1
 *
 *
 * Copyright (c) 2002 The Apache Software Foundation.  All rights 
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer. 
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:  
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The names "WSIF" and "Apache Software Foundation" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written 
 *    permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache",
 *    nor may "Apache" appear in their name, without prior written
 *    permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 * ====================================================================
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the Apache Software Foundation and was
 * originally based on software copyright (c) 2001, 2002, International
 * Business Machines, Inc., http://www.apache.org.  For more
 * information on the Apache Software Foundation, please see
 * <http://www.apache.org/>.
 */

package shop;

import java.util.*;
/**
 * Creation date: (8/4/2001 2:25:19 PM)
 * @author <a href="mailto:gpfau@de.ibm.com">Gerhard Pfau</a>
 */
public class ShoppingCart_Java {
    private int fieldTotal = 0;

    private String fieldFirstName;
    private String fieldLastName;
    private Address fieldAddress;
    private String fieldCustomerNumber;

    private Order fieldOrder;

    private static Orders fieldAllOrders = new Orders();
    
    public ShoppingCart_Java() {
        super();
    }
    
    public ShoppingCart_Java(
        String firstName,
        String lastName,
        Address address,
        String customerNumber)
        throws CreateException {
        super();

        fieldFirstName = firstName;
        fieldLastName = lastName;
        fieldAddress = address;
        fieldCustomerNumber = customerNumber;

        fieldOrder = new Order(customerNumber);
    }
    
    public int addItem(
        String itemNumber,
        Item item,
        String itemName,
        int itemQuantity)
        throws InvalidItemException, OutOfStockException {
        if (itemQuantity > 10)
            throw new OutOfStockException(
                "There are less then '"
                    + itemQuantity
                    + "' pieces of '"
                    + itemName
                    + "' in stock");

        if ((itemNumber == null)
            || (itemName == null)
            || (itemNumber.equals(""))
            || (itemName.equals("")))
            throw new InvalidItemException(
                "Invalid item: Number = '" + itemNumber + "' Name = '" + itemName + "'");

        item.setNumber(itemNumber);
        item.setName(itemName);
        item.setQuantity(itemQuantity);
        item.setPrice(100); // at the moment everything costs 100 currency units :-)

        fieldOrder.addItem(itemNumber, item);

        fieldTotal += (item.getPrice()*item.getQuantity());

        return fieldTotal;
    }
    
    public static Orders queryOrders(String customerNumber)
        throws EmptyResultException {
        return fieldAllOrders.getOrders(customerNumber);
    }
    
    public void emptyOrder(String customerNumber)
    {
    	fieldOrder.empty();
    	fieldTotal = 0;
    }
    
    public long submitOrder(
        CreditCardInfo creditCardInfo,
        AirMilesContainer airMilesContainer) {
        long orderConfirmationNumber = System.currentTimeMillis();
        fieldOrder.setConfirmationNumber(orderConfirmationNumber);
        fieldAllOrders.add(fieldOrder);
        fieldOrder = null;
        airMilesContainer.addMiles(1000);
        return orderConfirmationNumber;
    }
}
